@@ -161,10 +161,10 @@ def get_post_prot_dir(
 
     Notes
     -----
-    This function is (currently) only called for the tools that run after
-    Prodigal (and in the future, after other protein-prediction tools),
+    This function is (currently) only called for the softwares that run after
+    Prodigal (and in the future, after other protein-prediction softwares),
     since the protein prediction throughout the pipeline can be called after
-    different tools (e.g., after metawrap_refine, after drep, or, for long
+    different softwares (e.g., after metawrap_refine, after drep, or, for long
     read data, after error correction). Hence, editing the output directory
     to reflect the provenance and thus obtain different output folders if
     the pipeline is re-run for different paths at the Prodigal step.
@@ -198,7 +198,7 @@ def genome_key(
         tech: str,
         sam_group: str,
         genome: str = ''
-) -> str:
+) -> tuple:
     """Get a concatenation of the variables fields to split the commands as
     separate jobs later when writing out.
 
@@ -213,12 +213,12 @@ def genome_key(
 
     Returns
     -------
-    key : str
-        Concatenation of variables names for the current analytic level
+    key : tuple
+        Variables names for the current analytic level
     """
-    key = '_'.join([tech, sam_group])
+    key = (tech, sam_group)
     if genome:
-        key += '_' + genome
+        key += (genome,)
     return key
 
 
@@ -253,10 +253,11 @@ def genome_out_dir(
     key : str
         Concatenation of variables names for the current analytic level
     """
-    post_prot_dir = get_post_prot_dir(self, fasta)
-    self.soft.dir = post_prot_dir.replace('${SCRATCH_FOLDER}', '')
+    # post_prot_dir = get_post_prot_dir(self, fasta)
+    # self.soft.dir = post_prot_dir.replace('${SCRATCH_FOLDER}', '')
 
-    out_dir = '/'.join([post_prot_dir, tech])
+    # out_dir = '/'.join([post_prot_dir, tech])
+    out_dir = '/'.join([self.dir, tech])
     if self.sam_pool:
         out_dir += '/%s' % self.sam_pool
     if sam_group != self.sam_pool:
@@ -302,10 +303,12 @@ def check_input(
         typ = 'nuclassemble'
         if name in ['search_diamond', 'search_hmmer', 'macsyfinder']:
             typ = 'assemble'
-        is_type = (self.softs['plass'].params['type'] != typ)
-        if prev == 'plass' and is_type and not raw:
-            print('[%s] illumina annotation if plass type: %s' % (name, typ))
-            return True
+        if not raw:
+            is_type = (self.softs['plass'].params['type'] != typ)
+            if prev == 'plass' and is_type:
+                message = 'Illumina annotation if plass type: %s' % typ
+                self.soft.messages.add(message)
+                return True
     return False
 
 
@@ -313,10 +316,9 @@ def sample_inputs(
         self,
         techs=None,
         raw: bool = False,
-        index: int = 1
 ) -> dict:
     """Get per-sample input files per technology, depending on the current
-    tools.
+    softwares.
 
     Notes
     -----
@@ -345,7 +347,7 @@ def sample_inputs(
         .config
             Configurations
     techs : list
-        Technologies possibly used per sample for the current tools
+        Technologies possibly used per sample for the current softwares
     raw : bool
         Whether illumina data cna be processed as raw/per-sample paired reads
     index : int
@@ -354,7 +356,7 @@ def sample_inputs(
     Returns
     -------
     inputs : dict
-        Paths to inputs per-sample input files per technology
+        Paths to inputs per-sample input files and per technology
     """
     if techs is None:
         techs = ['illumina', 'pacbio', 'nanopore']
@@ -578,5 +580,3 @@ def add_folder(
     if self.soft.name == name:
         out += '/%s' % step
     return out
-
-
