@@ -11,11 +11,11 @@ import re
 import sys
 import yaml
 import glob
+import hashlib
 import itertools
 import pandas as pd
 from tabulate import tabulate
-from os.path import basename, dirname, isdir, isfile
-
+from os.path import basename, dirname, isdir, isfile, islink
 
 
 def read_yaml(
@@ -255,8 +255,11 @@ def status_update(
         inputs: list,
         pool: str = None,
         group: str = None,
-        genome: str = None
-) -> None:
+        genome: str = None,
+        message: str = None,
+        folder: bool = False,
+        software: str = ''
+) -> list:
     """Potentially add the fastq files to the status (files to generate).
 
     Parameters
@@ -276,15 +279,68 @@ def status_update(
         Name of the current co-assembly group
     genome : str
         MAGs/Genomes folder name or empty string (for assembly contigs)
+    message : str
+        Warning to show
+    folder : bool
+        Whether the paths are folders
+    software : str
+        Software name to allow collecting status
+
+    Returns
+    -------
+    to_dos : list
+        Paths to input file that need to be created (or whether they are links)
     """
-    to_dos = [x for x in inputs if to_do(x)]
-    if to_dos:
+    to_dos = get_to_dos(self, inputs, folder)
+    if to_dos and self.soft.name != software:
         if pool:
             self.soft.add_status(tech, pool, to_dos,
-                                 group=group, genome=genome)
+                                 group=group, genome=genome, message=message)
         else:
             self.soft.add_status(tech, self.sam_pool, to_dos,
-                                 group=group, genome=genome)
+                                 group=group, genome=genome, message=message)
+    return to_dos
+
+
+def get_to_dos(
+        self,
+        inputs: list,
+        folder: bool
+) -> list:
+    """Potentially add the fastq files to the status (files to generate).
+
+    Parameters
+    ----------
+    self : Commands class instance
+        .sam_pool : str
+            Sample name
+        .soft
+            Software class instance
+    inputs : list
+        Paths to input files
+    folder : bool
+        Whether the paths are folders
+
+    Returns
+    -------
+    to_dos : list
+        Paths to input file that need to be created (or whether they are links)
+    """
+    to_dos = []
+    for inp in inputs:
+        if folder:
+            to_do_inp = to_do(folder=inp)
+        else:
+            to_do_inp = to_do(inp)
+        if to_do_inp:
+            to_dos.append(inp)
+        if isinstance(inp, list):
+            inps = inp
+        else:
+            inps = [inp]
+        inps = [x.replace('${SCRATCH_FOLDER}', '') for x in inps]
+        self.soft.links.update({x: os.readlink(x) for x in inps if islink(x)})
+    return to_dos
 
 
 def get_roundtrip(io) -> dict:
@@ -398,6 +454,8 @@ def io_update(
         o_d=None,
         key=None
 ):
+    if not isinstance(key, tuple):
+        key = (key,)
     for (IO_fd, val) in [
         (('I', 'f'), i_f),
         (('I', 'd'), i_d),
@@ -407,25 +465,23 @@ def io_update(
         if not val:
             continue
         if isinstance(val, list):
-            if key:
-                self.outputs['io'][IO_fd].setdefault(key, set()).update(val)
-            else:
-                self.outputs['io'][IO_fd].update(val)
+            self.outputs['io'][IO_fd].setdefault(key, set()).update(val)
         elif isinstance(val, str):
-            if key:
-                self.outputs['io'][IO_fd].setdefault(key, set()).add(val)
-            else:
-                self.outputs['io'][IO_fd].add(val)
+            self.outputs['io'][IO_fd].setdefault(key, set()).add(val)
 
 
 def to_do(
         file: str = None,
         folder: str = None
 ) -> bool:
-    if file and isfile(file.replace('${SCRATCH_FOLDER}', '')):
-        return False
-    if folder and isdir(folder.replace('${SCRATCH_FOLDER}', '')):
-        return False
+    if file:
+        file = file.replace('${SCRATCH_FOLDER}', '')
+        if isfile(file) or islink(file):
+            return False
+    if folder:
+        folder = folder.replace('${SCRATCH_FOLDER}', '')
+        if (isdir(folder) or islink(folder)) and glob.glob('%s/*' % folder):
+            return False
     return True
 
 
@@ -444,7 +500,7 @@ def tech_specificity(
     Notes
     -----
     This behaviour is common to all software functions and therefore
-    justifies this function, and some tools of a workflow ar not designed
+    justifies this function, and some softwares of a workflow ar not designed
     for some technologies so the pipeline should pass through these while
     retaining the files available for a next step.
     For example, the reads merging can only happen on the 'illumina' data.
@@ -728,29 +784,90 @@ def print_status_table(
         print('done')
 
 
-def get_versions(version_fp) -> list:
-    """Get the different dates at which the current
-    pipeline configuration was run.
+def compute_hash(hash_string):
+    h = hashlib.blake2b(digest_size=10)
+    h.update(str(hash_string).encode('utf-8'))
+    hashed = str(h.hexdigest())
+    return hashed
+
+
+def get_md5(fp):
+    if isdir(fp):
+        return ''
+    md5 = hashlib.md5()
+    with open(fp, "rb") as f:
+        for chunk in f:
+            md5.update(chunk)
+    md5 = str(md5.hexdigest())
+    return md5
+
+
+def get_dates(run_fp) -> list:
+    """Get the different dates at which the current pipeline configuration
+    was run.
 
     Parameters
     ----------
-    version_fp
+    run_fp
         Path to the versioning file for this pipeline configuration
     Returns
     -------
-    versions : list
+    runs : list
         All the dates at which this pipeline configuration was run
     """
-    versions = []
-    if isfile(version_fp):
-        print('This pipeline configuration (softwares/parmas) was already run.')
-        with open(version_fp) as f:
+    runs = []
+    if isfile(run_fp):
+        with open(run_fp) as f:
             for line in f:
                 if line.startswith('Date'):
-                    versions.append(line.strip().split()[-1])
-    return versions
+                    runs.append(line.strip().split()[-1])
+    return runs
 
 
+def get_input_info(dat):
+    m = '%s input unit' % dat.shape[0]
+    if dat.shape[0] > 1:
+        m += 's'
+    info = '%s scripts (%s):' % (dat.name.nunique(), m)
+    return info
 
 
+def get_res_info(dat):
+    d = [(len(v), [len(x) for x in v.values()]) for v in dat.values() if v]
+    if not d:
+        return 'no data'
+    tech = '%s tech' % len(d)
+    if len(d) > 1:
+        tech += 's'
+    fs = sum([x[0] for x in d])
+    folders = '%s folder' % fs
+    if fs > 1:
+        folders += 's'
+    av = round(sum([round(sum(x[1])/len(x[1]), 2) for x in d]) / len(d), 2)
+    files = '%s file' % av
+    if av > 1:
+        files += 's'
+    info = '%s (%s and %s per folder)' % (tech, folders, files)
+    return info
 
+
+def get_size_info(dat):
+    sizes = {}
+    for folder, size_ in dat.items():
+        if size_ < 1024:
+            size = "%s bytes" % size_
+        elif size_ < 1024 * 1024:
+            size = "%s KB" % round(size_ / 1024, 2)
+        elif size_ < 1024 * 1024 * 1024:
+            size = "%s MB" % round(size_ / (1024 * 1024), 2)
+        elif size_ < 1024 * 1024 * 1024 * 1024:
+            size = "%s GB" % round(size_ / (1024 * 1024 * 1024), 2)
+        else:
+            size = str(size_)
+        if size_ > 0:
+            sizes[folder] = size
+    fs = '%s folder' % len(sizes)
+    if len(sizes) > 1:
+        fs += 's'
+    info = '%s (./%s)' % (fs, '; ./'.join(['='.join(x) for x in sizes.items()]))
+    return info, sizes
